<?php

namespace FiloBlu\Refilo\Model\Exporter;

use FiloBlu\Refilo\Model\Adapter\Mongo;
use Magento\Cms\Model\ResourceModel\Page\CollectionFactory as PageCollectionFactory;
use Magento\Framework\App\Config\ScopeConfigInterface;
use Magento\Framework\App\ResourceConnection;
use Magento\Store\Model\StoreManagerInterface;

class CmsPage
{
    /**
     * @var ResourceConnection
     */
    private $resourceConnection;
    /**
     * @var Mongo
     */
    private $mongo;
    /**
     * @var ScopeConfigInterface
     */
    private $scopeConfig;
    /**
     * @var StoreManagerInterface
     */
    private $storeManager;
    /**
     * @var PageCollectionFactory
     */
    protected $pageCollectionFactory;

    /**
     * Menu constructor.
     * @param ResourceConnection $resourceConnection
     * @param ScopeConfigInterface $scopeConfig
     * @param Mongo $mongo
     * @param StoreManagerInterface $storeManager
     * @param PageCollectionFactory $pageCollectionFactory
     */
    public function __construct(
        ResourceConnection $resourceConnection,
        ScopeConfigInterface $scopeConfig,
        Mongo $mongo,
        StoreManagerInterface $storeManager,
        PageCollectionFactory $pageCollectionFactory
    ) {
        $this->resourceConnection = $resourceConnection;
        $this->scopeConfig = $scopeConfig;
        $this->mongo = $mongo;
        $this->storeManager = $storeManager;
        $this->pageCollectionFactory = $pageCollectionFactory;
    }

    public function exportCmsPage()
    {
        foreach ($this->storeManager->getStores() as $key => $value) {
            $this->mongo->deleteDocumentsByProperties(
                $this->scopeConfig->getValue('mongo/general/mongo_general_database'),
                "contents_" . $value->getCode(),
                ['metacode' => 'page']
            );

            $collection = $this->pageCollectionFactory->create();
            $collection->addStoreFilter($value)->addFilter('is_active', 1);

            $bulk = [];
            foreach ($collection as $item) {
                $block = new \stdClass();

                $block->_id = 'page_' . $item->getId() . '_' . $value->getData('code');
                $block->metacode = 'page';
                $block->store = $value->getData('code');

                $block->content_id = (int) $item->getId();
                $block->url_key = $item->getIdentifier();
                $block->idx = $item->getIdentifier();
                $block->title = $item->getTitle();
                $block->type = 'page';
                $block->meta_title = $item->getMetaTitle();
                $block->meta_description = $item->getMetaDescription();
                $block->meta_keywords = $item->getMetaKeywords();
                $block->content_heading = $item->getContentHeading();
                $block->refilo_layout = $item->getRefiloLayout();
                $block->refilo_template = $item->getRefiloTemplate();
                $block->heading_visible = boolval($item->getHeadingVisible());
                $block->breadcrumbs_visible = boolval($item->getBreadcrumbsVisible());
                $block->og_data_image = $item->getOgDataImage();
                $block->header_type = $item->getHeaderType();
                $block->css_class = $item->getCssClass();
                $block->css_style = $item->getCssStyle();
                $block->robots = $item->getRobots();
                $block->status = $item->isActive();
                $block->content = $item->getContent();

                $bulk[] = $block;
            }

            try {
                $this->mongo->update(
                    '_id',
                    $bulk,
                    "contents_" . $value->getCode(),
                    true,
                    $this->scopeConfig->getValue('mongo/general/mongo_general_database')
                );
            } catch (MongoDB\Driver\Exception\Exception $e) {
                echo $e->getMessage();
            }

        }
    }
}
